<?php
namespace wisdmlabs\cpb;

/**
 * Personal data exporters.
 *
 * @since 6.2.0
 */
defined('ABSPATH') || exit;

/**
 * WC_Privacy_Exporters Class.
 */
class CpbPrivacyErasers
{
    /**
     * Finds and exports Enquiry data by email address.
     *
     * @since 6.2.0
     *
     * @param string $email_address The user email address.
     * @param int    $page          Page.
     *
     * @return array An array of personal data in name value pairs
     */
    public static function cpbAnonymizeGiftMsg($order)
    {
        if (!get_option('_wdmcpb_anonymize_mgs') || get_option('_wdmcpb_anonymize_mgs') == 'off') {
            return;
        }

        $existingLabels = getExistingMsgLabels();

        foreach ($order->get_items() as $item_id => $value) {
            $valueArraya = $value->get_data();
            $productID = $valueArraya['product_id'];
            $msgEnabled = get_post_meta($productID, '_wdm_enable_gift_message', true);

            if ("yes" != $msgEnabled) {
                continue;
            }

            $product = isset($valueArraya['product_id']) ? wc_get_product($productID) : "";
            if ($product->get_type() == 'wdm_bundle_product') {
                // $metaKey = get_post_meta($productID, '_wdm_gift_message_label', true);

                foreach ($value->get_data()['meta_data'] as $metaDatakey => $metaDataValue) {
                    $metaData = $metaDataValue->get_data();
                    if ($metaData['key'] == 'wdm_giftmsg_key') {
                        self::cpbAnonymizeData($item_id, 'wdm_giftmsg_key', $metaData['value']);
                    } elseif (in_array($metaData['key'], $existingLabels)) {
                        self::cpbAnonymizeData($item_id, $metaData['key'], $metaData['value']);
                    }
                    unset($metaDatakey);
                }
            }
        }
    }

    public static function cpbAnonymizeData($item_id, $metaKey, $value)
    {
        $anonymizedValue = wp_privacy_anonymize_data("text", $value);
        wc_update_order_item_meta($item_id, $metaKey, $anonymizedValue);
    }
}
